@@ -17,6 +17,7 @@ class TabelaAvlFpha1(TabelaCSV):
             LiteralField(size=14),
             IntegerField(size=7),
             FloatField(size=9, decimal_digits=5),
+            FloatField(size=8, decimal_digits=2),
             FloatField(size=12, decimal_digits=4),
             FloatField(size=13, decimal_digits=6),
             FloatField(size=13, decimal_digits=6),
@@ -29,6 +30,7 @@ class TabelaAvlFpha1(TabelaCSV):
         "nome_usina",
         "segmento_fpha",
         "fator_correcao",
+        "vazao_lateral_media",
         "rhs",
         "coeficiente_volume_util",
         "coeficiente_vazao_turbinada",
